RpcMessage

Struct RpcMessage 

pub struct RpcMessage {
    pub method: String,
    pub params: Params,
    pub sender: Sender<Result<Value, Error>>,
}
A message sent to the RpcClient. This is public so that the derive crate can generate a client.

Fields

method: String

The rpc method name.

params: Params

The rpc method parameters.

sender: Sender<Result<Value, Error>>

The oneshot channel to send the result of the rpc call to.